==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/PRECAUTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour PRECAUTIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PRECAUTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRECAUTIONCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONNUM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="auto_generated" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRECAUTIONID_Type", propOrder = {
    "precautioncode",
    "revisionnum",
    "organizationid",
    "description"
})
public class PRECAUTIONID_Type {

    @XmlElement(name = "PRECAUTIONCODE", required = true)
    protected String precautioncode;
    @XmlElement(name = "REVISIONNUM", required = true)
    protected QUANTITY revisionnum;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;
    @XmlAttribute(name = "auto_generated")
    protected Boolean auto_Generated;

    /**
     * Obtient la valeur de la propriété precautioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRECAUTIONCODE() {
        return precautioncode;
    }

    /**
     * Définit la valeur de la propriété precautioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRECAUTIONCODE(String value) {
        this.precautioncode = value;
    }

    /**
     * Obtient la valeur de la propriété revisionnum.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREVISIONNUM() {
        return revisionnum;
    }

    /**
     * Définit la valeur de la propriété revisionnum.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREVISIONNUM(QUANTITY value) {
        this.revisionnum = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Obtient la valeur de la propriété auto_Generated.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isAuto_Generated() {
        if (auto_Generated == null) {
            return true;
        } else {
            return auto_Generated;
        }
    }

    /**
     * Définit la valeur de la propriété auto_Generated.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAuto_Generated(Boolean value) {
        this.auto_Generated = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/PRECAUTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for PRECAUTIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PRECAUTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRECAUTIONCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONNUM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="auto_generated" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRECAUTIONID_Type", propOrder = {
    "precautioncode",
    "revisionnum",
    "organizationid",
    "description"
})
public class PRECAUTIONID_Type {

    @XmlElement(name = "PRECAUTIONCODE", required = true)
    protected String precautioncode;
    @XmlElement(name = "REVISIONNUM", required = true)
    protected QUANTITY revisionnum;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;
    @XmlAttribute(name = "auto_generated")
    protected Boolean auto_Generated;

    /**
     * Gets the value of the precautioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRECAUTIONCODE() {
        return precautioncode;
    }

    /**
     * Sets the value of the precautioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRECAUTIONCODE(String value) {
        this.precautioncode = value;
    }

    /**
     * Gets the value of the revisionnum property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREVISIONNUM() {
        return revisionnum;
    }

    /**
     * Sets the value of the revisionnum property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREVISIONNUM(QUANTITY value) {
        this.revisionnum = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the auto_Generated property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isAuto_Generated() {
        if (auto_Generated == null) {
            return true;
        } else {
            return auto_Generated;
        }
    }

    /**
     * Sets the value of the auto_Generated property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAuto_Generated(Boolean value) {
        this.auto_Generated = value;
    }

}
